Accelerator Brochure for HVAC Monitoring

# HVAC Monitoring
## Attributes
### Inefficient Operation | A condition that is present whenever the HVAC is running in ostensibly unnecessary environmental situations, resulting in inefficient use of power. Examples: Ambient temperature is within control bounds and does not warrant cooling Environmental conditions are such that HVAC system is operating outside of its range of capabilities |
## Requirements
### Compressor Power | Compressor Power as measured at the power supply of the equipment itself. |
Unit Of Measure Family: | kW
Type: | Signal
### Temperature | The ambient external temperature as measured in a neutral location away from HVAC inlet/outlet sites. Note that this value may be derived from equipment sensors with a suitable coefficient to account for location bias. |
Unit Of Measure Family: | F
Type: | Signal
Optional: | True